###########
Documenteer
###########

**Sphinx extensions, configurations, and tooling for Rubin Observatory documentation projects.**

Documenteer is developed on GitHub at https://github.com/lsst-sqre/documenteer.

Getting started
===============

.. toctree::
   :maxdepth: 1

   install
   changelog

Sphinx extensions
=================

Documenteer provides several Sphinx extensions.
These extensions are designed for Rubin Observatory documentation projects, but are may be generally useful:

.. toctree::
   :maxdepth: 2

   sphinx-extensions/index

Pipelines projects
==================

A guide to using Documenteer for LSST Science Pipelines documentation:

.. toctree::
   :maxdepth: 2

   pipelines/index

Technote projects
=================

A guide to writing reStructuredText-formatted Rubin Observatory technical notes (technotes) using Sphinx and Documenteer:

.. toctree::
   :maxdepth: 2

   technotes/index

Reference
=========

.. toctree::
   :maxdepth: 1

   api

Developer guide
===============

.. toctree::
   :maxdepth: 1

   dev/development
   dev/release
